Module platform

Module platform 

Supported host platforms (macOS arm64/x86_64, Linux x86_64, Windows x86_64). Host-platform detection and slug encoding for the four targets that Tableau’s Hyper API ships binaries for.

Enums

Platform
One of the four platforms that Tableau publishes a hyperd build for.