InstalledHyperd

Struct InstalledHyperd 

pub struct InstalledHyperd {
    pub binary_path: PathBuf,
    pub version: String,
    pub build_id: String,
    pub platform: Platform,
    pub cache_hit: bool,
}
Result of a successful install call.

Fields

binary_path: PathBuf

Absolute or relative path to the installed hyperd executable. Always under <dest_root>/current/.

version: String

Installed release version (for example, "0.0.24457").

build_id: String

Installed release build id (for example, "rc36858b6").

platform: Platform

Host platform this install targets.

cache_hit: bool

true if the versioned directory already existed and we skipped the download; false if we downloaded and extracted fresh bytes.